@@ -124,6 +124,17 @@ impl ChangesComponent {
         }
         false
     }
+
+    fn add_to_ignore(&mut self) -> Result<bool> {
+        if let Some(tree_item) = self.selection() {
+            sync::add_to_ignore(CWD, tree_item.info.full_path)?;
+            self.queue
+                .borrow_mut()
+                .push_back(InternalEvent::Update(NeedsUpdate::ALL));
+            return Ok(true);
+        }
+        Ok(false)
+    }
 }
 
 impl DrawableComponent for ChangesComponent {
@@ -159,6 +170,11 @@ impl Component for ChangesComponent {
                 some_selection,
                 self.focused(),
             ));
+            out.push(CommandInfo::new(
+                commands::IGNORE_ITEM,
+                some_selection,
+                self.focused(),
+            ));
         } else {
             out.push(CommandInfo::new(
                 commands::UNSTAGE_ITEM,
@@ -210,6 +226,13 @@ impl Component for ChangesComponent {
                     {
                         Ok(self.dispatch_reset_workdir())
                     }
+
+                    keys::STATUS_IGNORE_FILE
+                        if self.is_working_dir
+                            && !self.is_empty() =>
+                    {
+                        Ok(self.add_to_ignore()?)
+                    }
                     _ => Ok(false),
                 };
             }
