@@ -4,10 +4,11 @@ use super::{
 };
 use crate::{
     components::dialog_paragraph,
-    queue::{InternalEvent, Queue, ResetItem},
+    queue::{Action, InternalEvent, Queue},
     strings, ui,
     ui::style::Theme,
 };
+use anyhow::Result;
 use crossterm::event::{Event, KeyCode};
 use std::borrow::Cow;
 use strings::commands;
@@ -20,28 +21,35 @@ use tui::{
 
 ///
 pub struct ResetComponent {
-    target: Option<ResetItem>,
+    target: Option<Action>,
     visible: bool,
     queue: Queue,
     theme: Theme,
 }
 
 impl DrawableComponent for ResetComponent {
-    fn draw<B: Backend>(&mut self, f: &mut Frame<B>, _rect: Rect) {
+    fn draw<B: Backend>(
+        &mut self,
+        f: &mut Frame<B>,
+        _rect: Rect,
+    ) -> Result<()> {
         if self.visible {
-            let mut txt = Vec::new();
-            txt.push(Text::Styled(
-                Cow::from(strings::RESET_MSG),
+            let (title, msg) = self.get_text();
+
+            let txt = vec![Text::Styled(
+                Cow::from(msg),
                 self.theme.text_danger(),
-            ));
+            )];
 
             let area = ui::centered_rect(30, 20, f.size());
             f.render_widget(Clear, area);
             f.render_widget(
-                dialog_paragraph(strings::RESET_TITLE, txt.iter()),
+                dialog_paragraph(title, txt.iter()),
                 area,
             );
         }
+
+        Ok(())
     }
 }
 
@@ -65,25 +73,26 @@ impl Component for ResetComponent {
         visibility_blocking(self)
     }
 
-    fn event(&mut self, ev: Event) -> bool {
+    fn event(&mut self, ev: Event) -> Result<bool> {
         if self.visible {
             if let Event::Key(e) = ev {
                 return match e.code {
                     KeyCode::Esc => {
                         self.hide();
-                        true
+                        Ok(true)
                     }
 
                     KeyCode::Enter => {
                         self.confirm();
-                        true
+                        Ok(true)
                     }
 
-                    _ => true,
+                    _ => Ok(true),
                 };
             }
         }
-        false
+
+        Ok(false)
     }
 
     fn is_visible(&self) -> bool {
@@ -94,8 +103,10 @@ impl Component for ResetComponent {
         self.visible = false
     }
 
-    fn show(&mut self) {
-        self.visible = true
+    fn show(&mut self) -> Result<()> {
+        self.visible = true;
+
+        Ok(())
     }
 }
 
@@ -110,18 +121,37 @@ impl ResetComponent {
         }
     }
     ///
-    pub fn open_for_path(&mut self, item: ResetItem) {
-        self.target = Some(item);
-        self.show();
+    pub fn open(&mut self, a: Action) -> Result<()> {
+        self.target = Some(a);
+        self.show()?;
+
+        Ok(())
     }
     ///
     pub fn confirm(&mut self) {
-        if let Some(target) = self.target.take() {
+        if let Some(a) = self.target.take() {
             self.queue
                 .borrow_mut()
-                .push_back(InternalEvent::ResetItem(target));
+                .push_back(InternalEvent::ConfirmedAction(a));
         }
 
         self.hide();
     }
+
+    fn get_text(&self) -> (&str, &str) {
+        if let Some(ref a) = self.target {
+            return match a {
+                Action::Reset(_) => (
+                    strings::CONFIRM_TITLE_RESET,
+                    strings::CONFIRM_MSG_RESET,
+                ),
+                Action::StashDrop(_) => (
+                    strings::CONFIRM_TITLE_STASHDROP,
+                    strings::CONFIRM_MSG_STASHDROP,
+                ),
+            };
+        }
+
+        ("", "")
+    }
 }
