@@ -45,7 +45,7 @@ impl ItemBatch {
     }
 
     ///
-    pub fn index_offset(&self) -> usize {
+    pub const fn index_offset(&self) -> usize {
         self.index_offset
     }
 
