@@ -15,6 +15,7 @@ const fn with_mod(
 }
 
 pub const TAB_TOGGLE: KeyEvent = no_mod(KeyCode::Tab);
+pub const TAB_TOGGLE_REVERSE: KeyEvent = no_mod(KeyCode::BackTab);
 pub const FOCUS_WORKDIR: KeyEvent = no_mod(KeyCode::Char('1'));
 pub const FOCUS_STAGE: KeyEvent = no_mod(KeyCode::Char('2'));
 pub const FOCUS_RIGHT: KeyEvent = no_mod(KeyCode::Right);
@@ -41,6 +42,7 @@ pub const ENTER: KeyEvent = no_mod(KeyCode::Enter);
 pub const STATUS_STAGE_FILE: KeyEvent = no_mod(KeyCode::Enter);
 pub const STATUS_RESET_FILE: KeyEvent =
     with_mod(KeyCode::Char('D'), KeyModifiers::SHIFT);
+pub const STATUS_IGNORE_FILE: KeyEvent = no_mod(KeyCode::Char('i'));
 pub const STASHING_SAVE: KeyEvent = no_mod(KeyCode::Char('s'));
 pub const STASHING_TOGGLE_UNTRACKED: KeyEvent =
     no_mod(KeyCode::Char('u'));
@@ -49,3 +51,4 @@ pub const STASHING_TOGGLE_INDEX: KeyEvent =
 pub const STASH_APPLY: KeyEvent = no_mod(KeyCode::Enter);
 pub const STASH_DROP: KeyEvent =
     with_mod(KeyCode::Char('D'), KeyModifiers::SHIFT);
+pub const CMD_BAR_TOGGLE: KeyEvent = no_mod(KeyCode::Char('.'));
