@@ -63,7 +63,7 @@ pub mod commands {
     );
     ///
     pub static DIFF_HOME_END: CommandText = CommandText::new(
-        "Jump up/down [home,end,shift+up,shift+down]",
+        "Jump up/down [home,end,\u{11014}up,\u{2191}down]",
         "scroll to top or bottom of diff",
         CMD_GROUP_DIFF,
     );
@@ -140,6 +140,12 @@ pub mod commands {
         "revert changes in selected file or entire path",
         CMD_GROUP_CHANGES,
     );
+    ///
+    pub static IGNORE_ITEM: CommandText = CommandText::new(
+        "Ignore [i]",
+        "Add file or path to .gitignore",
+        CMD_GROUP_CHANGES,
+    );
 
     ///
     pub static STATUS_FOCUS_LEFT: CommandText = CommandText::new(
@@ -155,7 +161,7 @@ pub mod commands {
     );
     ///
     pub static QUIT: CommandText = CommandText::new(
-        "Quit [ctrl+c]",
+        "Quit [^c]",
         "quit gitui application",
         CMD_GROUP_GENERAL,
     );
