@@ -1,14 +1,29 @@
 mod scrolllist;
-
+pub(crate) mod style;
+use crate::ui::style::Theme;
 use scrolllist::ScrollableList;
 use tui::{
     backend::Backend,
     layout::{Constraint, Direction, Layout, Rect},
-    style::{Color, Modifier, Style},
     widgets::{Block, Borders, Text},
     Frame,
 };
 
+/// return the scroll position (line) necessary to have the `selection` in view if it is not already
+pub fn calc_scroll_top(
+    current_top: usize,
+    height_in_lines: usize,
+    selection: usize,
+) -> usize {
+    if current_top + height_in_lines <= selection {
+        selection.saturating_sub(height_in_lines) + 1
+    } else if current_top > selection {
+        selection
+    } else {
+        current_top
+    }
+}
+
 /// use layouts to create a rects that
 /// centers inside `r` and sizes `percent_x`/`percent_x` of `r`
 pub fn centered_rect(
@@ -61,24 +76,18 @@ pub fn draw_list<'b, B: Backend, L>(
     items: L,
     select: Option<usize>,
     selected: bool,
+    theme: Theme,
 ) where
     L: Iterator<Item = Text<'b>>,
 {
-    let mut style_border = Style::default().fg(Color::DarkGray);
-    let mut style_title = Style::default();
-    if selected {
-        style_border = style_border.fg(Color::Gray);
-        style_title = style_title.modifier(Modifier::BOLD);
-    }
     let list = ScrollableList::new(items)
         .block(
             Block::default()
                 .title(title)
                 .borders(Borders::ALL)
-                .title_style(style_title)
-                .border_style(style_border),
+                .title_style(theme.title(selected))
+                .border_style(theme.block(selected)),
         )
-        .scroll(select.unwrap_or_default())
-        .style(Style::default().fg(Color::White));
+        .scroll(select.unwrap_or_default());
     f.render_widget(list, r)
 }
